aboutsummaryrefslogtreecommitdiffstats
path: root/policy_manager/stm/zipc/StateTransitionor/hud/layer
diff options
context:
space:
mode:
authorfukubayashi.akio <fukubayashi.akio@genetec.co.jp>2019-06-06 17:55:08 +0900
committerfukubayashi.akio <fukubayashi.akio@genetec.co.jp>2019-06-06 17:55:08 +0900
commitac17da7010c6bd90240a641d503991ca5d0cb41a (patch)
treea8311029c5c7bc92a64694a1d8d2339b4e1ca38b /policy_manager/stm/zipc/StateTransitionor/hud/layer
parent98006b6538c5be44350746ec3756f004a5c68af8 (diff)
Add chage remote app
Signed-off-by: fukubayashi.akio <fukubayashi.akio@genetec.co.jp>
Diffstat (limited to 'policy_manager/stm/zipc/StateTransitionor/hud/layer')
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.c179
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.h41
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.c50
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.h14
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.c179
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.h41
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.c49
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.h14
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud.c18
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud_func.c2
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left.c32
-rwxr-xr-xpolicy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left_func.c2
12 files changed, 594 insertions, 27 deletions
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.c
new file mode 100755
index 0000000..52744cd
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.c
@@ -0,0 +1,179 @@
+/************************************************************/
+/* Zhud_apps_hud_apps.c */
+/* hud_apps State transition model source file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#include "../../../ZST_include.h"
+
+/* State management variable */
+static uint8_t Zhud_apps_hud_appsState[ZHUD_APPS_HUD_APPSSTATENOMAX];
+
+static void Zhud_apps_hud_appss0e0( void );
+static void Zhud_apps_hud_appss1e0( void );
+static void Zhud_apps_hud_appss1e1( void );
+static void Zhud_apps_hud_appss0Event( void );
+static void Zhud_apps_hud_appss1Event( void );
+
+/****************************************/
+/* Action function */
+/* STM : hud_apps */
+/* State : none( No 0 ) */
+/* Event : ara_normal( No 0 ) */
+/****************************************/
+static void Zhud_apps_hud_appss0e0( void )
+{
+ Zhud_apps_hud_appsState[ZHUD_APPS_HUD_APPS] = ( uint8_t )ZHUD_APPS_HUD_APPSS1;
+ stm_hud_apps_start_activity_general();
+}
+
+/****************************************/
+/* Action function */
+/* STM : hud_apps */
+/* State : general( No 1 ) */
+/* Event : ara_normal( No 0 ) */
+/****************************************/
+static void Zhud_apps_hud_appss1e0( void )
+{
+ stm_hud_apps_start_activity_general();
+}
+
+/****************************************/
+/* Action function */
+/* STM : hud_apps */
+/* State : general( No 1 ) */
+/* Event : ctg_receiver( No 1 ) */
+/****************************************/
+static void Zhud_apps_hud_appss1e1( void )
+{
+ Zhud_apps_hud_appsState[ZHUD_APPS_HUD_APPS] = ( uint8_t )ZHUD_APPS_HUD_APPSS0;
+ stm_hud_apps_start_activity_none();
+}
+
+/****************************************/
+/* Event appraisal function */
+/* STM : hud_apps */
+/* State : none( No 0 ) */
+/****************************************/
+static void Zhud_apps_hud_appss0Event( void )
+{
+ /*evt_activate*/
+ if( g_stm_event == StmEvtNoActivate )
+ {
+ /*ctg_receiver*/
+ if( g_stm_category == StmCtgNoReceiver )
+ {
+ /*ara_normal*/
+ if( g_stm_area == StmAreaNoNormal )
+ {
+ Zhud_apps_hud_appss0e0();
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+}
+
+/****************************************/
+/* Event appraisal function */
+/* STM : hud_apps */
+/* State : general( No 1 ) */
+/****************************************/
+static void Zhud_apps_hud_appss1Event( void )
+{
+ /*evt_activate*/
+ if( g_stm_event == StmEvtNoActivate )
+ {
+ /*ctg_receiver*/
+ if( g_stm_category == StmCtgNoReceiver )
+ {
+ /*ara_normal*/
+ if( g_stm_area == StmAreaNoNormal )
+ {
+ Zhud_apps_hud_appss1e0();
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ /*evt_deactivate*/
+ else if( g_stm_event == StmEvtNoDeactivate )
+ {
+ /*ctg_receiver*/
+ if( g_stm_category == StmCtgNoReceiver )
+ {
+ Zhud_apps_hud_appss1e1();
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+}
+
+/****************************************/
+/* Event call function */
+/* STM : hud_apps */
+/****************************************/
+void stm_hud_apps_event_call( void )
+{
+ stm_hud_apps_start_stm();
+ switch( Zhud_apps_hud_appsState[ZHUD_APPS_HUD_APPS] )
+ {
+ case ZHUD_APPS_HUD_APPSS0:
+ Zhud_apps_hud_appss0Event();
+ break;
+ case ZHUD_APPS_HUD_APPSS1:
+ Zhud_apps_hud_appss1Event();
+ break;
+ default:
+ /*Not accessible to this else (default).*/
+ break;
+ }
+}
+
+/****************************************/
+/* Initial function */
+/* STM : hud_apps */
+/****************************************/
+void stm_hud_apps_initialize( void )
+{
+ Zhud_apps_hud_appsState[ZHUD_APPS_HUD_APPS] = ( uint8_t )ZHUD_APPS_HUD_APPSS0;
+ stm_hud_apps_start_activity_none();
+}
+
+/****************************************/
+/* Terminate function */
+/* STM : hud_apps */
+/****************************************/
+void Zhud_apps_hud_appsTerminate( void )
+{
+ Zhud_apps_hud_appsState[ZHUD_APPS_HUD_APPS] = ( uint8_t )ZHUD_APPS_HUD_APPSTERMINATE;
+}
+
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.h b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.h
new file mode 100755
index 0000000..77063df
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps.h
@@ -0,0 +1,41 @@
+/************************************************************/
+/* Zhud_apps_hud_apps.h */
+/* hud_apps State transition model header file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#ifndef ZHEADER_ZHUD_APPS_HUD_APPS_H
+#define ZHEADER_ZHUD_APPS_HUD_APPS_H
+
+/*State management variable access define*/
+#define ZHUD_APPS_HUD_APPS ( 0U )
+#define ZHUD_APPS_HUD_APPSS0 ( 0U )
+#define ZHUD_APPS_HUD_APPSS1 ( 1U )
+#define ZHUD_APPS_HUD_APPSSTATENOMAX ( 1U )
+
+/*End state define*/
+#define ZHUD_APPS_HUD_APPSEND ( 2U )
+/*Terminate state define*/
+#define ZHUD_APPS_HUD_APPSTERMINATE ( ZHUD_APPS_HUD_APPSEND + 1U )
+
+/*State no define*/
+#define ZHUD_APPS_HUD_APPSS0STATENO ( 0U )
+#define ZHUD_APPS_HUD_APPSS1STATENO ( 1U )
+
+/*State serial no define*/
+#define ZHUD_APPS_HUD_APPSS0STATESERIALNO ( 0U )
+#define ZHUD_APPS_HUD_APPSS1STATESERIALNO ( 1U )
+
+/*Event no define*/
+#define ZHUD_APPS_HUD_APPSE0EVENTNO ( 0U )
+#define ZHUD_APPS_HUD_APPSE1EVENTNO ( 1U )
+
+/*Event serial no define*/
+#define ZHUD_APPS_HUD_APPSE0EVENTSERIALNO ( 0U )
+#define ZHUD_APPS_HUD_APPSE1EVENTSERIALNO ( 1U )
+
+/*Extern function*/
+extern void stm_hud_apps_event_call( void );
+extern void stm_hud_apps_initialize( void );
+extern void Zhud_apps_hud_appsTerminate( void );
+
+#endif
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.c
new file mode 100755
index 0000000..b11ef61
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.c
@@ -0,0 +1,50 @@
+/************************************************************/
+/* Zhud_apps_hud_apps_func.c */
+/* Function and variable source file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#include "../../../ZST_include.h"
+
+/*************************************************************
+ Function definition
+*************************************************************/
+
+/**
+ * stm_hud_apps_initialize_variable
+ */
+void stm_hud_apps_initialize_variable() {
+ g_stm_prv_state.layer[StmLayerNoApps].state = StmLayoutNoGenNml;
+ g_stm_prv_state.layer[StmLayerNoApps].changed = STM_FALSE;
+
+ g_stm_crr_state.layer[StmLayerNoApps].state = StmLayoutNoGenNml;
+ g_stm_crr_state.layer[StmLayerNoApps].changed = STM_FALSE;
+}
+
+/**
+ * stm_hud_apps_start_stm
+ */
+void stm_hud_apps_start_stm() {
+ if (g_stm_event == StmEvtNoUndo) {
+ // nop
+ }
+ else {
+ g_stm_prv_state.layer[StmLayerNoApps].state = g_stm_crr_state.layer[StmLayerNoApps].state;
+ }
+ g_stm_crr_state.layer[StmLayerNoApps].changed = STM_FALSE;
+}
+
+/*
+ * @name stm_hud_apps_start_activity_none
+ */
+void stm_hud_apps_start_activity_none() {
+ g_stm_crr_state.layer[StmLayerNoApps].state = StmLayoutNoNone;
+ g_stm_crr_state.layer[StmLayerNoApps].changed = STM_TRUE;
+}
+
+/**
+ * stm_hud_apps_start_activity_general
+ */
+void stm_hud_apps_start_activity_general(){
+ g_stm_crr_state.layer[StmLayerNoApps].state = StmLayoutNoGenNml;
+ g_stm_crr_state.layer[StmLayerNoApps].changed = STM_TRUE;
+}
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.h b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.h
new file mode 100755
index 0000000..161107f
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/apps/Zhud_apps_hud_apps_func.h
@@ -0,0 +1,14 @@
+/************************************************************/
+/* Zhud_apps_hud_apps_func.h */
+/* Function and variable header file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#ifndef ZHEADER_ZHUD_APPS_HUD_APPS_FUNC_H
+#define ZHEADER_ZHUD_APPS_HUD_APPS_FUNC_H
+
+extern void stm_hud_apps_initialize_variable();
+extern void stm_hud_apps_start_stm();
+extern void stm_hud_apps_start_activity_none();
+extern void stm_hud_apps_start_activity_general();
+
+#endif
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.c
new file mode 100755
index 0000000..73d7784
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.c
@@ -0,0 +1,179 @@
+/************************************************************/
+/* Zhud_near_apps_hud_near_apps.c */
+/* hud_near_apps State transition model source file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#include "../../../ZST_include.h"
+
+/* State management variable */
+static uint8_t Zhud_near_apps_hud_near_appsState[ZHUD_NEAR_APPS_HUD_NEAR_APPSSTATENOMAX];
+
+static void Zhud_near_apps_hud_near_appss0e0( void );
+static void Zhud_near_apps_hud_near_appss1e0( void );
+static void Zhud_near_apps_hud_near_appss1e1( void );
+static void Zhud_near_apps_hud_near_appss0Event( void );
+static void Zhud_near_apps_hud_near_appss1Event( void );
+
+/****************************************/
+/* Action function */
+/* STM : hud_near_apps */
+/* State : none( No 0 ) */
+/* Event : ara_upper_left( No 0 ) */
+/****************************************/
+static void Zhud_near_apps_hud_near_appss0e0( void )
+{
+ Zhud_near_apps_hud_near_appsState[ZHUD_NEAR_APPS_HUD_NEAR_APPS] = ( uint8_t )ZHUD_NEAR_APPS_HUD_NEAR_APPSS1;
+ stm_hud_near_apps_start_activity_upper_left();
+}
+
+/****************************************/
+/* Action function */
+/* STM : hud_near_apps */
+/* State : upper_left( No 1 ) */
+/* Event : ara_upper_left( No 0 ) */
+/****************************************/
+static void Zhud_near_apps_hud_near_appss1e0( void )
+{
+ stm_hud_near_apps_start_activity_upper_left();
+}
+
+/****************************************/
+/* Action function */
+/* STM : hud_near_apps */
+/* State : upper_left( No 1 ) */
+/* Event : ctg_receiver2( No 1 ) */
+/****************************************/
+static void Zhud_near_apps_hud_near_appss1e1( void )
+{
+ Zhud_near_apps_hud_near_appsState[ZHUD_NEAR_APPS_HUD_NEAR_APPS] = ( uint8_t )ZHUD_NEAR_APPS_HUD_NEAR_APPSS0;
+ stm_hud_near_apps_start_activity_none();
+}
+
+/****************************************/
+/* Event appraisal function */
+/* STM : hud_near_apps */
+/* State : none( No 0 ) */
+/****************************************/
+static void Zhud_near_apps_hud_near_appss0Event( void )
+{
+ /*evt_activate*/
+ if( g_stm_event == StmEvtNoActivate )
+ {
+ /*ctg_receiver2*/
+ if( g_stm_category == StmCtgNoReceiver2 )
+ {
+ /*ara_upper_left*/
+ if( g_stm_area == StmAreaNoUpperLeft )
+ {
+ Zhud_near_apps_hud_near_appss0e0();
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+}
+
+/****************************************/
+/* Event appraisal function */
+/* STM : hud_near_apps */
+/* State : upper_left( No 1 ) */
+/****************************************/
+static void Zhud_near_apps_hud_near_appss1Event( void )
+{
+ /*evt_activate*/
+ if( g_stm_event == StmEvtNoActivate )
+ {
+ /*ctg_receiver2*/
+ if( g_stm_category == StmCtgNoReceiver2 )
+ {
+ /*ara_upper_left*/
+ if( g_stm_area == StmAreaNoUpperLeft )
+ {
+ Zhud_near_apps_hud_near_appss1e0();
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ /*evt_deactivate*/
+ else if( g_stm_event == StmEvtNoDeactivate )
+ {
+ /*ctg_receiver2*/
+ if( g_stm_category == StmCtgNoReceiver2 )
+ {
+ Zhud_near_apps_hud_near_appss1e1();
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+ }
+ else
+ {
+ /*Else and default design have not done.*/
+ /*Please confirm the STM and design else and default.*/
+ }
+}
+
+/****************************************/
+/* Event call function */
+/* STM : hud_near_apps */
+/****************************************/
+void stm_hud_near_apps_event_call( void )
+{
+ stm_hud_near_apps_start_stm();
+ switch( Zhud_near_apps_hud_near_appsState[ZHUD_NEAR_APPS_HUD_NEAR_APPS] )
+ {
+ case ZHUD_NEAR_APPS_HUD_NEAR_APPSS0:
+ Zhud_near_apps_hud_near_appss0Event();
+ break;
+ case ZHUD_NEAR_APPS_HUD_NEAR_APPSS1:
+ Zhud_near_apps_hud_near_appss1Event();
+ break;
+ default:
+ /*Not accessible to this else (default).*/
+ break;
+ }
+}
+
+/****************************************/
+/* Initial function */
+/* STM : hud_near_apps */
+/****************************************/
+void stm_hud_near_apps_initialize( void )
+{
+ Zhud_near_apps_hud_near_appsState[ZHUD_NEAR_APPS_HUD_NEAR_APPS] = ( uint8_t )ZHUD_NEAR_APPS_HUD_NEAR_APPSS0;
+ stm_hud_near_apps_start_activity_none();
+}
+
+/****************************************/
+/* Terminate function */
+/* STM : hud_near_apps */
+/****************************************/
+void Zhud_near_apps_hud_near_appsTerminate( void )
+{
+ Zhud_near_apps_hud_near_appsState[ZHUD_NEAR_APPS_HUD_NEAR_APPS] = ( uint8_t )ZHUD_NEAR_APPS_HUD_NEAR_APPSTERMINATE;
+}
+
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.h b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.h
new file mode 100755
index 0000000..081e2bc
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps.h
@@ -0,0 +1,41 @@
+/************************************************************/
+/* Zhud_near_apps_hud_near_apps.h */
+/* hud_near_apps State transition model header file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#ifndef ZHEADER_ZHUD_NEAR_APPS_HUD_NEAR_APPS_H
+#define ZHEADER_ZHUD_NEAR_APPS_HUD_NEAR_APPS_H
+
+/*State management variable access define*/
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPS ( 0U )
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSS0 ( 0U )
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSS1 ( 1U )
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSSTATENOMAX ( 1U )
+
+/*End state define*/
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSEND ( 2U )
+/*Terminate state define*/
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSTERMINATE ( ZHUD_NEAR_APPS_HUD_NEAR_APPSEND + 1U )
+
+/*State no define*/
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSS0STATENO ( 0U )
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSS1STATENO ( 1U )
+
+/*State serial no define*/
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSS0STATESERIALNO ( 0U )
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSS1STATESERIALNO ( 1U )
+
+/*Event no define*/
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSE0EVENTNO ( 0U )
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSE1EVENTNO ( 1U )
+
+/*Event serial no define*/
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSE0EVENTSERIALNO ( 0U )
+#define ZHUD_NEAR_APPS_HUD_NEAR_APPSE1EVENTSERIALNO ( 1U )
+
+/*Extern function*/
+extern void stm_hud_near_apps_event_call( void );
+extern void stm_hud_near_apps_initialize( void );
+extern void Zhud_near_apps_hud_near_appsTerminate( void );
+
+#endif
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.c
new file mode 100755
index 0000000..7c8fb61
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.c
@@ -0,0 +1,49 @@
+/************************************************************/
+/* Zhud_near_apps_hud_near_apps_func.c */
+/* Function and variable source file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#include "../../../ZST_include.h"
+
+/*************************************************************
+ Function definition
+ *************************************************************/
+
+/**
+ * stm_hud_near_apps_initialize_variable
+ */
+void stm_hud_near_apps_initialize_variable() {
+ g_stm_prv_state.layer[StmLayerNoNearApps].state = StmLayoutNoUpperLeft;
+ g_stm_prv_state.layer[StmLayerNoNearApps].changed = STM_FALSE;
+
+ g_stm_crr_state.layer[StmLayerNoNearApps].state = StmLayoutNoUpperLeft;
+ g_stm_crr_state.layer[StmLayerNoNearApps].changed = STM_FALSE;
+}
+
+/**
+ * stm_hud_near_apps_start_stm
+ */
+void stm_hud_near_apps_start_stm() {
+ if (g_stm_event == StmEvtNoUndo) {
+ // nop
+ } else {
+ g_stm_prv_state.layer[StmLayerNoNearApps].state =
+ g_stm_crr_state.layer[StmLayerNoNearApps].state;
+ }
+ g_stm_crr_state.layer[StmLayerNoNearApps].changed = STM_FALSE;
+}
+/*
+ * @name stm_hud_near_apps_start_activity_none
+ */
+void stm_hud_near_apps_start_activity_none() {
+ g_stm_crr_state.layer[StmLayerNoNearApps].state = StmLayoutNoNone;
+ g_stm_crr_state.layer[StmLayerNoNearApps].changed = STM_TRUE;
+}
+
+/**
+ * stm_hud_near_apps_start_activity_upper_left
+ */
+void stm_hud_near_apps_start_activity_upper_left() {
+ g_stm_crr_state.layer[StmLayerNoNearApps].state = StmLayoutNoUpperLeft;
+ g_stm_crr_state.layer[StmLayerNoNearApps].changed = STM_TRUE;
+}
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.h b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.h
new file mode 100755
index 0000000..3c0bdff
--- /dev/null
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/near_apps/Zhud_near_apps_hud_near_apps_func.h
@@ -0,0 +1,14 @@
+/************************************************************/
+/* Zhud_near_apps_hud_near_apps_func.h */
+/* Function and variable header file */
+/* ZIPC Designer Version 1.2.1 */
+/************************************************************/
+#ifndef ZHEADER_ZHUD_NEAR_APPS_HUD_NEAR_APPS_FUNC_H
+#define ZHEADER_ZHUD_NEAR_APPS_HUD_NEAR_APPS_FUNC_H
+
+extern void stm_hud_near_apps_initialize_variable();
+extern void stm_hud_near_apps_start_stm();
+extern void stm_hud_near_apps_start_activity_none();
+extern void stm_hud_near_apps_start_activity_upper_left();
+
+#endif
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud.c
index 26569e3..b2dbcfc 100755
--- a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud.c
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud.c
@@ -18,7 +18,7 @@ static void Zremote_hud_remote_huds1Event( void );
/* Action function */
/* STM : remote_hud */
/* State : none( No 0 ) */
-/* Event : ara_normal( No 0 ) */
+/* Event : ara_hud_normal( No 0 ) */
/****************************************/
static void Zremote_hud_remote_huds0e0( void )
{
@@ -29,8 +29,8 @@ static void Zremote_hud_remote_huds0e0( void )
/****************************************/
/* Action function */
/* STM : remote_hud */
-/* State : general( No 1 ) */
-/* Event : ara_normal( No 0 ) */
+/* State : remote_hud( No 1 ) */
+/* Event : ara_hud_normal( No 0 ) */
/****************************************/
static void Zremote_hud_remote_huds1e0( void )
{
@@ -40,7 +40,7 @@ static void Zremote_hud_remote_huds1e0( void )
/****************************************/
/* Action function */
/* STM : remote_hud */
-/* State : general( No 1 ) */
+/* State : remote_hud( No 1 ) */
/* Event : ctg_general( No 1 ) */
/****************************************/
static void Zremote_hud_remote_huds1e1( void )
@@ -62,8 +62,8 @@ static void Zremote_hud_remote_huds0Event( void )
/*ctg_general*/
if( g_stm_category == StmCtgNoGeneral )
{
- /*ara_normal*/
- if( g_stm_area == StmAreaNoNormal )
+ /*ara_hud_normal*/
+ if( g_stm_area == StmAreaNoHUDNormal )
{
Zremote_hud_remote_huds0e0();
}
@@ -89,7 +89,7 @@ static void Zremote_hud_remote_huds0Event( void )
/****************************************/
/* Event appraisal function */
/* STM : remote_hud */
-/* State : general( No 1 ) */
+/* State : remote_hud( No 1 ) */
/****************************************/
static void Zremote_hud_remote_huds1Event( void )
{
@@ -99,8 +99,8 @@ static void Zremote_hud_remote_huds1Event( void )
/*ctg_general*/
if( g_stm_category == StmCtgNoGeneral )
{
- /*ara_normal*/
- if( g_stm_area == StmAreaNoNormal )
+ /*ara_hud_normal*/
+ if( g_stm_area == StmAreaNoHUDNormal )
{
Zremote_hud_remote_huds1e0();
}
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud_func.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud_func.c
index 9a1c17f..2134467 100755
--- a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud_func.c
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud/Zremote_hud_remote_hud_func.c
@@ -45,6 +45,6 @@ void stm_remote_hud_start_activity_none() {
* stm_remote_hud_start_activity_general
*/
void stm_remote_hud_start_activity_general(){
- g_stm_crr_state.layer[StmLayerNoRemoteHUD].state = StmLayoutNoGenNml;
+ g_stm_crr_state.layer[StmLayerNoRemoteHUD].state = StmLayoutNoRmtHud;
g_stm_crr_state.layer[StmLayerNoRemoteHUD].changed = STM_TRUE;
}
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left_func.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left_func.c
index 2ed9d3b..05ecf4f 100755
--- a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left_func.c
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left_func.c
@@ -44,6 +44,6 @@ void stm_remote_hud_up_left_start_activity_none() {
* stm_remote_hud_up_left_start_activity_upper_left
*/
void stm_remote_hud_up_left_start_activity_upper_left(){
- g_stm_crr_state.layer[StmLayerNoRemoteHUDUpperLeft].state = StmLayoutNoRmtUpLeft;
+ g_stm_crr_state.layer[StmLayerNoRemoteHUDUpperLeft].state = StmLayoutNoRmtHudUpLeft;
g_stm_crr_state.layer[StmLayerNoRemoteHUDUpperLeft].changed = STM_TRUE;
}
diff --git a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left.c b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left.c
index 32c5041..40cf614 100755
--- a/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left.c
+++ b/policy_manager/stm/zipc/StateTransitionor/hud/layer/remote_hud_upper_left/Zremote_hud_upper_left_remote_hud_up_left.c
@@ -18,7 +18,7 @@ static void Zremote_hud_upper_left_remote_hud_up_lefts1Event( void );
/* Action function */
/* STM : remote_hud_up_left */
/* State : none( No 0 ) */
-/* Event : ara_upper_left( No 0 ) */
+/* Event : ara_hud_upper_left( No 0 ) */
/****************************************/
static void Zremote_hud_upper_left_remote_hud_up_lefts0e0( void )
{
@@ -29,8 +29,8 @@ static void Zremote_hud_upper_left_remote_hud_up_lefts0e0( void )
/****************************************/
/* Action function */
/* STM : remote_hud_up_left */
-/* State : upper_left( No 1 ) */
-/* Event : ara_upper_left( No 0 ) */
+/* State : remote_hud_upper_left( No 1 ) */
+/* Event : ara_hud_upper_left( No 0 ) */
/****************************************/
static void Zremote_hud_upper_left_remote_hud_up_lefts1e0( void )
{
@@ -40,8 +40,8 @@ static void Zremote_hud_upper_left_remote_hud_up_lefts1e0( void )
/****************************************/
/* Action function */
/* STM : remote_hud_up_left */
/* State : upper_left( No 1 ) */
/* Event : ctg_general( No 1 ) */
/****************************************/
static void Zremote_hud_upper_left_remote_hud_up_lefts1e1( void )
{
@@ -59,11 +59,11 @@ static void Zremote_hud_upper_left_remote_hud_up_lefts0Event( void )
/*evt_activate*/
if( g_stm_event == StmEvtNoActivate )
{
- /*ctg_general*/
- if( g_stm_category == StmCtgNoGeneral )
+ /*ctg_speed*/
+ if( g_stm_category == StmCtgNoSpeed )
{
- /*ara_upper_left*/
- if( g_stm_area == StmAreaNoUpperLeft )
+ /*ara_hud_upper_left*/
+ if( g_stm_area == StmAreaNoHUDUpperLeft )
{
Zremote_hud_upper_left_remote_hud_up_lefts0e0();
}
@@ -89,18 +89,18 @@ static void Zremote_hud_upper_left_remote_hud_up_lefts0Event( void )
/****************************************/
/* Event appraisal function */
/* STM : remote_hud_up_left */
-/* State : upper_left( No 1 ) */
+/* State : remote_hud_upper_left( No 1 ) */
/****************************************/
static void Zremote_hud_upper_left_remote_hud_up_lefts1Event( void )
{
/*evt_activate*/
if( g_stm_event == StmEvtNoActivate )
{
- /*ctg_general*/
- if( g_stm_category == StmCtgNoGeneral )
+ /*ctg_speed*/
+ if( g_stm_category == StmCtgNoSpeed )
{
- /*ara_upper_left*/
- if( g_stm_area == StmAreaNoUpperLeft )
+ /*ara_hud_upper_left*/
+ if( g_stm_area == StmAreaNoHUDUpperLeft )
{
Zremote_hud_upper_left_remote_hud_up_lefts1e0();
}
@@ -119,8 +119,8 @@ static void Zremote_hud_upper_left_remote_hud_up_lefts1Event( void )
/*evt_deactivate*/
else if( g_stm_event == StmEvtNoDeactivate )
{
- /*ctg_general*/
- if( g_stm_category == StmCtgNoGeneral )
+ /*ctg_speed*/
+ if( g_stm_category == StmCtgNoSpeed )
{
Zremote_hud_upper_left_remote_hud_up_lefts1e1();
}
@@ -40,8 +40,8 @@ static void Zremote_hud_upper_left_remote_hud_up_lefts1e0( void )
/* Action function */
/* STM : remote_hud_up_left */
-/* State : upper_left( No 1 ) */
-/* Event : ctg_general( No 1 ) */
+/* State : remote_hud_upper_left( No 1 ) */
+/* Event : ctg_speed( No 1 ) */
/****************************************/
static void Zremote_hud_upper_left_remote_hud_up_lefts1e1( void )